.. _module-docs:

Modules Reference
=================

.. module:: diofant

Because every feature of Diofant must have a test case, when you are not sure how
to use something, just look into the ``tests/`` directories, find that feature
and read the tests for it, that will tell you everything you need to know.

Most of the things are already documented though in this document, that is
automatically generated using Diofant's docstrings.

Click the  "modules" (:ref:`modindex`) link in the top right corner to easily
access any Diofant module, or use this contents:

.. toctree::
   :maxdepth: 2

   core.rst
   combinatorics/index.rst
   ntheory.rst
   concrete.rst
   functions/index.rst
   geometry/index.rst
   integrals.rst
   logic.rst
   domains.rst
   matrices/index.rst
   polys/index.rst
   printing.rst
   interactive.rst
   plotting.rst
   series.rst
   sets.rst
   simplify/simplify.rst
   stats.rst
   solvers/index.rst
   tensor/index.rst
   utilities/index.rst
   parsing.rst
   calculus/index.rst
   diffgeom.rst
   vector/index.rst
